@@ -798,6 +798,53 @@ class Database:
         """
         self._update(table="File", id_=id_, updates=updates, commit=commit)
 
+    def reset_file_statuses(self,
+        existing_statuses: List[FileStatus],
+        new_status: FileStatus,
+        commit: bool = True,
+    ) -> None:
+        """
+        Reset file statuses to a new value.
+
+        All file records having one of the specified existing statuses
+        will have their status changed to the new status.
+
+        Parameters
+        ----------
+        existing_statuses : list of FileStatus
+            The file statuses to be changed.
+        new_status : FileStatus
+            The status to which all file records with one of the existing
+            statuses will be changed.
+        commit : bool
+            Determines whether changes will be committed to the database.
+            This may be false if the changes are part of a transaction.
+        """
+        status_map = {
+            f"status{i:02}": existing_statuses[i].value
+            for i in range(len(existing_statuses))
+        }
+
+        sql = """
+            UPDATE File
+            SET file_status_id = :new_status_id
+            WHERE
+                file_status_id IN (
+            """
+
+        for key in status_map:
+            sql += f":{key}, "
+
+        # Remove comma + space and add closing parenthesis.
+        sql = sql[:-2] + ")"
+
+        status_map["new_status_id"] = new_status.value
+        cursor = self.connection.cursor()
+        cursor.execute(sql, status_map)
+
+        if commit:
+            self.connection.commit()
+
     def get_parser(self, parser_id: int) -> Optional[Dict]:
         """Get a parser record data given a parser id."""
         sql = "SELECT * FROM Parser WHERE id = :parser_id"
@@ -1181,10 +1228,21 @@ class Database:
 
         return last_id
 
-    def get_file_count(self) -> int:
+    def get_file_count(self, include_root_folders: bool = False) -> int:
         """Get number of files in the database."""
         cursor = self.connection.cursor()
-        sql = "SELECT COUNT(*) AS file_count FROM File"
+
+        if include_root_folders:
+            sql = "SELECT COUNT(*) AS file_count FROM File"
+        else:
+            # As of 2/15/2023, a File record corresponds to a HyperThought
+            # root folder iff its path is null.
+            sql = """
+            SELECT COUNT(*) AS file_count
+            FROM File
+            WHERE path IS NOT NULL
+            """
+
         cursor.execute(sql)
         result = cursor.fetchone()
         return result["file_count"]
